.. _tutorials-chat:

============================
Websocket Chat Server
============================

The code for this example is located in the :mod:`examples.chat.manage` module.

.. automodule:: examples.chat.manage